@@ -24,6 +24,9 @@ def map_type(definition: dict, imported: bool = False):
     type_name = definition['type']
 
     if type_name == 'string':
+        fmt = definition.get('format')
+        if fmt == 'date-time':
+            return 'time.Time'
         return 'string'
     if type_name == 'boolean':
         return 'bool'
@@ -52,7 +55,9 @@ def map_type(definition: dict, imported: bool = False):
 
 def from_string(definition: dict, param: str) -> str:
     type_name = map_type(definition)
-    if type_name == 'boolean':
+    if type_name == 'time.Time':
+        return f'time.Parse(time.RFC3339, {param})'
+    if type_name == 'bool':
         return f'strconv.ParseBool({param})'
     if type_name == 'float64':
         return f'strconv.ParseFloat({param}, 64)'
@@ -121,6 +126,24 @@ def cast(value, definition: dict) -> str:
     return value
 
 
+def label(text: str) -> str:
+    if '_' in text:
+        text = "".join(label(t) for t in text.split('_'))
+    text = text[0].upper() + text[1:]
+    return text
+
+
+def private(text: str) -> str:
+    if '_' in text:
+        text = "".join(label(t) for t in text.split('_'))
+    text = text[0].lower() + text[1:]
+    return text
+
+
+def comment(text: str) -> str:
+    return '\n'.join('// ' + line for line in text.splitlines())
+
+
 def main():
     parser = ArgumentParser(description='Zombie swagger 2.0')
     parser.add_argument('--swagger', '-s', type=Path, default=(Path.cwd() / "swagger.yaml"),
@@ -134,9 +157,11 @@ def main():
 
     env = Environment(loader=FileSystemLoader(args.templates))
     env.filters['map_type'] = map_type
-    env.filters['label'] = lambda x: x[0].upper() + x[1:]
+    env.filters['label'] = label
+    env.filters['private'] = private
     env.filters['path'] = path
     env.filters['cast'] = cast
+    env.filters['comment'] = comment
     env.filters['from_string'] = from_string
     env.filters['to_string'] = to_string
     env.filters['secured'] = lambda x: len(x.get('security', [])) > 0
